Skip to contents

Return a specific bill based on a legiscan bill_id

Usage

getBill(billID = NULL, legiKey = NULL)

Arguments

billID

bill_id integer value

legiKey

32 character string provided by legiscan

Value

A list of bill details, including nested sponsors, history, texts, roll calls, and session information.

Examples

if (FALSE) { # \dontrun{
getBill(billID = 1633853)
} # }