Add or remove bills from the monitor list
setMonitor.RdInteract with GAITS to add or remove bills from the monitor list of the account associated with the legiKey provided, or set a stance on monitored bills
Value
A base data frame containing bill_id and result for returned
bills. Bill IDs are character strings taken from the response names; results
contain the API values for the requested action.
Examples
if (FALSE) { # \dontrun{
setMonitor(billIDs = c(150334, 141690), action = "monitor")
setMonitor(billIDs = 1533377, action = "set", stance = "support")
} # }