Skip to contents

Every request requires a legiscan api key to be set in order to complete a request.

Usage

setlegiKey(APIkey, install = FALSE, overwrite = FALSE)

Arguments

APIkey

32 character string given to you by legiscan.com

install

Store the key in your .Renviron file for use across sessions

overwrite

Overwrite a previously installed key in your .Renviron file

Value

With install = TRUE, the supplied API key is returned invisibly after writing it to .Renviron. Otherwise, an invisible logical value indicates whether setting the environment variable succeeded.