Returns a legiscan Master List for a specified session or the most recent regular session if only state is provided
Usage
getMasterList(sessionID = NULL, state = NULL, legiKey = NULL)
Arguments
- sessionID
Session id integer value. Can be found with `getSessions`
- state
US state abbreviation
- legiKey
32 character string provided by legiscan
Value
Master List in dataframe format
Examples
if (FALSE) { # \dontrun{
getMasterList(sessionID = 2108)
getMasterList(state = "TX")
} # }