Return legiscan Master List for change detection
getMasterListRaw.RdReturns a Master List of bill_id and change_hash values for a specified session or the most recent regular session if only state is provided. Optimized for detecting which bills have changed and need updating via `getBill`.
Value
A data frame (tibble) of bill IDs and change hashes, excluding
session metadata. Nonempty results retain the API columns. An empty bill
list returns zero rows with integer bill_id and character
number and change_hash columns. Use nrow() to test
whether there are any bills.