Return associated monitor list for change detection
getMonitorListRaw.RdReturn bill_id and change_hash values from the monitor list of the account associated with the legiKey provided. Optimized for detecting which bills have changed and need updating via `getBill`.
Value
A data frame (tibble) of monitored bill IDs and change hashes.
Nonempty results retain the API columns. An empty monitor list returns zero
rows with integer bill_id, stance, and status columns
and character state, number, and change_hash columns.
Use nrow() to test whether there are any bills.