getRollCall.Rd
Return vote detail summary for provided Roll Call and a nested list of individual votes
getRollCall(rollCallID = NULL, legiKey = NULL)
Roll Call ID integer
32 character string provided by legiscan
Summary of Vote and nested list of individual votes by people id
if (FALSE) { # \dontrun{ getRollCall(rollCallID = 1361957) } # }