Add or remove bills from the monitor list
setMonitor.RdInteract with GAITS to add or remove bills from the monitor list of the account associated with the legiKey provided, or set a stance on monitored bills
Examples
if (FALSE) { # \dontrun{
setMonitor(billIDs = c(150334, 141690), action = "monitor")
setMonitor(billIDs = 1533377, action = "set", stance = "support")
} # }